@@ -355,18 +355,6 @@ class GoogleCode(BugTracker):
         # https://code.google.com/feeds/issues/p/googleappengine/
         feed = feedparser.parse(self.show_url(bugId), agent=useragent())
         print(feed)
-        """</content><link rel='replies' type='application/atom+xml' href='http://code.google.com/feeds/issues/p/jsonbot/issues/1/comments/full'/>
-           <link rel='alternate' type='text/html' href='http://code.google.com/p/jsonbot/issues/detail?id=1'/>
-           <link rel='self' type='application/atom+xml' href='https://code.google.com/feeds/issues/p/jsonbot/issues/full/1'/>
-           <author><name>bthate</name><uri>/u/bthate/</uri></author>
-           <issues:closedDate>2010-04-02T19:25:16.000Z</issues:closedDate>
-           <issues:id>1</issues:id>
-           <issues:label>Type-Defect</issues:label>
-           <issues:label>Priority-Medium</issues:label>
-           <issues:owner><issues:uri>/u/bthate/</issues:uri><issues:username>bthate</issues:username></issues:owner>
-           <issues:stars>1</issues:stars>
-           <issues:state>closed</issues:state>
-           <issues:status>Fixed</issues:status></entry>"""
         if not feed.entries: return {}
         print(list(feed.entries[0].keys()))
         """[u'issues_label', 'updated_parsed', 'links', u'issues_owner', u'issues_closeddate', 'href', u'issues_status', 'id', u'issues_uri', 'published_parsed', 
